@@ -1,7 +1,7 @@
 package File::RsyBak;
 
-our $DATE = '2015-10-21'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2015-10-22'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010001;
 use strict;
@@ -178,7 +178,7 @@ _
     },
 };
 sub backup {
-    require File::Flock;
+    require File::Flock::Retry;
     require File::Path;
     require File::Which;
 
@@ -211,10 +211,7 @@ sub backup {
                 "$target->{abs_path}: $!"];
     }
 
-    return [409, "Error: Can't lock $target->{abs_path}/.lock, ".
-                "perhaps another backup process is running"]
-        unless File::Flock::lock("$target->{abs_path}/.lock", undef,
-                                 "nonblocking");
+    my $lock = File::Flock::Retry->lock("$target->{abs_path}/.lock");
 
     if ($backup) {
         _backup(
@@ -229,8 +226,6 @@ sub backup {
         _rotate($target->{abs_path}, $histories);
     }
 
-    File::Flock::unlock("$target->{abs_path}/.lock");
-
     [200, "OK"];
 }
 
@@ -382,7 +377,7 @@ File::RsyBak - Backup files/directories with histories, using rsync
 
 =head1 VERSION
 
-This document describes version 0.28 of File::RsyBak (from Perl distribution File-RsyBak), released on 2015-10-21.
+This document describes version 0.29 of File::RsyBak (from Perl distribution File-RsyBak), released on 2015-10-22.
 
 =head1 SYNOPSIS
 
